# interact.js Pro License Agreement

<a id="order-form"></a>
## Order Form

These terms, together with the **Order Form** referencing them, make up a software license agreement. **Developer** and **Customer** are identified on the _Order Form_.

<a id="scope"></a>
## Scope

1. **Software** means the software that the _Order Form_ specifies.

2. **Covered Versions** depend on the _Order Form_:

    1. If the _Order Form_ specifies a particular version, _Covered Versions_ include only that version.

    2. If the _Order Form_ specifies a version range, such as "1.y.z", then _Covered Versions_ include the latest _Generally Available_ version in that range on the date of this agreement, as well as any new versions within that range that _Developer_ makes _Generally Available_ during the term of this agreement.

    3. If the _Order Form_ does not specify a particular version or version range, then _Covered Versions_ include the latest _Generally Available_ version on the date of this agreement, as well as any new versions that _Developer_ makes _Generally Available_ during the term of this agreement.

    4. A version of the _Software_ is **Generally Available** if _Developer_ offers it to the public for use in production systems. Versions that _Developer_ designates with labels like "Alpha", "Beta", "Testing", and "Preview" are not _Generally Available_.

3. **Use Limits** means any limits on use of the _Software_ that the _Order Form_ specifies, such as such as maximum numbers of _Users_, _Running Instances_, or _Concurrent Users_.

<a id="developers-obligations"></a>
## Developer's Obligations

<a id="provide-a-download"></a>
### Provide a Download

_Developer_ agrees to make the _Latest Version of the Software_ available for _Customer Personnel_ to download, free of charge, via the Internet, and to give _Notice_ of a URL on written request.

<a id="make-sure-customer-can-download-software-dependencies"></a>
### Make Sure Customer Can Download Software Dependencies

_Developer_ agrees to make sure any _Software Dependencies_, other than _Software Dependencies_ identified as exceptions on the _Order Form_, are _Publicly Licensed_ and generally available for _Customer_ to download, free of charge, from a _Public Software Repository_. _Developer_ does not agree to any service-level agreement or other specific guarantee about any _Public Software Repository_.

<a id="provide-any-license-keys"></a>
### Provide Any License Keys

_Developer_ agrees to give _Customer_ _Notice_ of any _License Keys_ required to use the _Latest Version of the Software_ on entering into this agreement. _Developer_ agrees to give _Customer_ _Notice_ of any new _License Keys_ required to use any new _Latest Version of the Software_ when released.

<a id="publish-documentation"></a>
### Publish Documentation

_Developer_ agrees to publish the _Documentation_ so that _Customer Personnel_ can read it, free of charge, via the Internet. _Developer_ agrees to make sure the _Documentation_ contains instructions that enable a system administrator experienced with a supported operating system to install, configure, and run the _Latest Version of the Software_.

<a id="refund-prepaid-fees-for-removed-functionality"></a>
### Refund Prepaid Fees for Removed Functionality

If _Developer_ changes or removes functionality from the _Latest Version of the Software_ that was part of the functionality of the last _Latest Version of the Software_, substantially reducing how useful the _Software_ is to _Customer_, and _Customer_ ends this agreement within three calendar months of the change, citing the change, _Developer_ agrees to refund any _Prepaid Fees_.

<a id="keep-malicious-code-out-of-the-software"></a>
### Keep Malicious Code Out of the Software

_Developer_ agrees to keep the _Software_ free of malicious code, such as computer worms and viruses.

<a id="limit-validation-code-in-the-software"></a>
### Limit Validation Code in the Software

With the following exceptions, _Developer_ agrees to keep the _Software_ free of code that automatically limits or disables its functionality:

1. _Developer_ may include code that limits or disables functionality on failure to validate _License Keys_.

2. _Developer_ may include code that automatically limits or disables functionality based on automatic monitoring of _Use Limits_.

3. _Developer_ may include code that reports data about _License Keys_ validation and _Use Limits_ monitoring back to _Developer_ systems.

<a id="protect-customer-from-liability"></a>
### Protect Customer from Liability

So long as _Customer_ has met its obligations under [Pay Fees](#pay-fees):

<a id="indemnify-customer"></a>
#### Indemnify Customer

Subject to [Indemnification Process](#indemnification-process), _Developer_ agrees to give _Customer_ _Indemnification_ for _Legal Claims_ by others alleging that _Permitted Use of the Software_ does any of these:

1. infringes any copyright, trademark, or trade secret

2. infringes any patent covered by _Developer_'s patent guarantee under [Provide Assurance About Patents](#provide-assurance-about-patents)

3. breaks any law

<a id="provide-assurance-about-patents"></a>
#### Provide Assurance About Patents

_Developer_'s guarantee about patents depends on the _Order Form_:

<a id="standard-patent-guarantee"></a>
##### Standard Patent Guarantee

If the _Order Form_ specifies a standard patent guarantee, or does not specify any particular patent guarantee, then _Developer_ guarantees that as of the date of this agreement, _Developer_ is not aware of any patent that _Developer_ would infringe by licensing the _Software_ under this agreement, or that _Customer_ would infringe by _Permitted Use of the Software_.

<a id="extended-patent-guarantee"></a>
##### Extended Patent Guarantee

If the _Order Form_ specifies an extended patent guarantee, then _Developer_ guarantees that _Developer_ will not infringe any patent by licensing the _Software_ under this agreement, and that _Customer_ will not infringe any patent by _Permitted Use of the Software_.

<a id="give-notice-of-infringement-claims"></a>
#### Give Notice of Infringement Claims

_Developer_ agrees to give _Customer_ prompt _Notice_ of any _Infringement Claim_.

<a id="protect-customer-after-this-agreement-ends"></a>
### Protect Customer After this Agreement Ends

[Indemnify Customer](#indemnify-customer) continues after this agreement ends.

<a id="customers-obligations"></a>
## Customer's Obligations

<a id="pay-fees"></a>
### Pay Fees

1. _Customer_ agrees to pay the license fees that the _Order Form_ specifies.

2. _Customer_ agrees to pay those fees when the _Order Form_ specifies, or if not specified, on entering into this agreement.

3. _Customer_ agrees to pay using the method that the _Order Form_ specifies.

4. _Customer_ agrees to pay all tax on fees under this agreement, except tax _Developer_ owes on income.

5. [Pay Fees](#pay-fees) continues after this agreement ends.

<a id="keep-license-keys-confidential-and-secure"></a>
### Keep License Keys Confidential and Secure

_Customer_ agrees to share _License Keys_ only as needed to make _Permitted Use of the Software_, and to secure _License Keys_ at least as well as _Customer_'s own confidential information.

<a id="follow-rules-about-use"></a>
### Follow Rules About Use

_Customer_ agrees not to:

1. reverse engineer the _Software_

2. exceed the _Use Limits_

3. circumvent any access controls or other limits of the _Software_

4. circumvent code permitted under [Limit Validation Code in the Software](#limit-validation-code-in-the-software)

5. violate another's _Intellectual Property Right_ or other legal right using the _Software_

6. breach any agreement using the _Software_

7. break any law using the _Software_

8. break any import or export law by exporting or reexporting the _Software_

9. remove proprietary notices from the _Software_ or the _Documentation_

10. use the _Software_ to analyze it against any competitive product or service

11. disclose data about the performance of the _Software_

<a id="enforce-rules-about-use"></a>
### Enforce Rules About Use

_Customer_ agrees to make sure _Customer Personnel_ and other personnel abide by [Keep License Keys Confidential and Secure](#keep-license-keys-confidential-and-secure) and [Follow Rules About Use](#follow-rules-about-use).

<a id="indemnify-developer"></a>
### Indemnify Developer

Subject to [Indemnification Process](#indemnification-process), _Customer_ agrees to give _Developer_ _Indemnification_ from _Legal Claims_ by others based on:

1. _Customer_ breach of this agreement

2. _Use of the Software at Customer's Own Risk_

3. misuse of _Customer_'s _License Keys_

<a id="intellectual-property"></a>
## Intellectual Property

<a id="software-copyright-license"></a>
### Software Copyright License

_Developer_ grants _Customer_ and each of the _Users_ a _Standard License_, for any copyrights in _Covered Versions_ of the _Software_ that _Developer_ can license, to copy, install, back up, and make _Permitted Use of the Software_.

<a id="software-patent-license"></a>
### Software Patent License

_Developer_ grants _Customer_ and each of the _Users_ a _Standard License_, for any patents _Developer_ can license or becomes able to license, to make _Permitted Use of the Software_.

<a id="documentation-copyright-license"></a>
### Documentation Copyright License

_Developer_ grants _Customer_ and _Customer Personnel_ a _Standard License_, for any copyrights in the _Documentation_ that _Developer_ can license, to read, back up, and copy the _Documentation_.

<a id="standard-license-terms"></a>
### Standard License Terms

**Standard License** means a nonexclusive license for the term of this agreement that is conditional on payment of all fees as required by this agreement and limited by the _Use Limits_.

<a id="publicity-license"></a>
### Publicity License

If the _Order Form_ specifies publicity rights, then _Developer_ may identify _Customer_ as a customer to current and potential customers, and may list _Customer_'s business name and logo in promotional materials, such as _Developer_'s websites, during the term of this agreement.

<a id="no-other-licenses"></a>
### No Other Licenses

Apart from the licenses in [Intellectual Property](#intellectual-property), this agreement does not license or assign any _Intellectual Property Right_.

<a id="dual-licensing"></a>
### Dual Licensing

If any part of the _Software_ is or becomes _Publicly Licensed_ during the term of this agreement:

1. During the term of this agreement, _Customer_ must abide by this agreement, not the _Public License_.

2. After this agreement ends, _Customer_ must abide by the _Public License_.

<a id="liability"></a>
## Liability

<a id="agreed-legal-remedies"></a>
### Agreed Legal Remedies

1. Each side's only legal remedy for _Legal Claims_ covered by _Indemnification_ will be _Indemnification_.

2. _Customer_'s only legal remedy for changes to software functionality in the _Latest Version of the Software_ will be refunds under [Refund Prepaid Fees for Removed Functionality](#refund-prepaid-fees-for-removed-functionality).

<a id="excuses"></a>
### Excuses

Neither side will be liable for any failure or delay in meeting any obligation under this agreement caused by:

1. failure of the other side or its personnel to meet their obligations under this agreement

2. actions done or delayed on written request of the other side

3. fire, flood, earthquake, and other natural disasters

4. declared and undeclared wars, acts of terrorism, sabotage, riots, civil disorders, rebellions, and revolutions

5. extraordinary malfunction of Internet infrastructure, data centers, or communications utilities

6. government actions taken in response to any of these causes

<a id="only-express-warranties"></a>
### Only Express Warranties

!!! Except for _Developer_'s obligations in [Developer's Obligations](#developers-obligations), _Developer_ provides the _Software_ as is, without any warranty.

<a id="limited-damages"></a>
### Limited Damages

<a id="damages-limit"></a>
#### Damages Limit

!!! Subject to [Damages Limit Exceptions](#damages-limit-exceptions), neither side's total liability for breach of this agreement will not exceed the amount _Customer_ paid _Developer_ under this agreement during the twelve months before the first claim is filed. This limit applies even if the side liable is advised that the other may suffer damages, and even if _Customer_ paid nothing at all.

<a id="damages-limit-exceptions"></a>
#### Damages Limit Exceptions

[Limited Damages](#limited-damages) does not limit damages for breach of:

1. [Enforce Rules About Use](#enforce-rules-about-use)

2. [Indemnify Customer](#indemnify-customer)

3. [Pay Fees](#pay-fees)

4. [Follow Rules About Use](#follow-rules-about-use)

5. [Indemnify Developer](#indemnify-developer)

<a id="term-and-renewal"></a>
## Term and Renewal

This agreement will continue for the initial period the _Order Form_ specifies. If the _Order Form_ specifies automatic renewal, then this agreement will renew automatically for more periods, each as long as the initial period.

<a id="changes"></a>
## Changes

<a id="changes-customer-may-make"></a>
### Changes Customer May Make

Subject to [Change Process](#change-process):

1. _Customer_ may end this agreement at any time.

2. If the _Order Form_ specifies flexible pricing for increased _Use Limits_, _Customer_ may increase its _Use Limits_ within that pricing at any time. Changes to _Use Limits_ take effect as soon as _Customer_ pays the added fees.

<a id="changes-developer-may-make"></a>
### Changes Developer May Make

Subject to [Change Process](#change-process):

1. If _Customer_ breaches this agreement, _Developer_ gives _Notice_ of the breach, and _Customer_ does not cure the breach within 30 calendar days of receiving _Notice_, _Developer_ may end this agreement immediately.

2. _Developer_ may end this agreement when it would otherwise automatically renew by giving _Notice_ at least 30 calendar days ahead of time.

3. _Developer_ may take any of these steps in response to an _Infringement Claim_:

    1. _Developer_ may release a new version of the _Software_ so that _Permitted Use of the Software_ will no longer infringe or break the law.

    2. If the problem is infringement, _Developer_ may get a license for _Customer_ so that _Permitted Use of the Software_ will no longer infringe.

    3. If the problem is illegality, _Developer_ may get the government approvals, licenses, or other requirements needed to abide by the law.

    4. _Developer_ may refund any _Prepaid Fees_ and end this agreement immediately.

<a id="process"></a>
## Process

<a id="indemnification-process"></a>
### Indemnification Process

Both sides agree that to receive _Indemnification_ under this agreement, they must give _Notice_ of any covered _Legal Claims_ quickly, allow the other side to control investigation, defense, and settlement, and cooperate with those efforts. Both sides agree that if they fail to give _Notice_ of any covered _Legal Claims_ quickly, _Indemnification_ will not cover amounts that could have been defended against or mitigated if _Notice_ had been given quickly. Both sides agree that if they take control of the defense and settlement of any _Legal Claims_ covered by _Indemnification_, they will not agree to any settlements that admit fault or impose obligations on the other side without their _Permission_.

<a id="notice-process"></a>
### Notice Process

Both sides agree that to give _Notice_ under this agreement, the side giving _Notice_ must send by e-mail to the address the recipient given with its signature, or to a different address given later for _Notice_ going forward. If either side finds that e-mail can't be delivered to the e-mail address given, it may give _Notice_ by registered mail to the address on file for the recipient with the state under whose laws it is organized.

<a id="change-process"></a>
### Change Process

_Customer_ and _Developer_ agree to make changes allowed under this agreement by _Notice_.

<a id="general-contract-terms"></a>
## General Contract Terms

<a id="governing-law"></a>
### Governing Law

The law of the state of _Developer's Address_ will govern this agreement

<a id="no-cisg"></a>
### No CISG

The United Nations Convention on Contracts for the International Sale of Goods will not apply to this agreement.

<a id="no-ucita"></a>
### No UCITA

As far as the law allows, the Uniform Computer Information Transactions Act will not apply to this agreement.

<a id="government-procurement"></a>
### Government Procurement

The _Software_ is commercial computer software, and the _Documentation_ is commercial computer software documentation. Both were developed exclusively at private expense. If _Customer_'s procurement is subject to Federal Acquisition Regulation 12.212 or Defense Federal Acquisition Regulation Supplement 227.7202, _Customer_'s rights will be only those stated in this agreement.

<a id="whole-agreement"></a>
### Whole Agreement

Both sides intend the _Order Form_ and these terms as the final, complete, and only expression of their terms about licensing of the _Software_. But this agreement does not affect any separate nondisclosure agreement _Developer_ and _Customer_ may have.

<a id="enforcement"></a>
### Enforcement

Only _Developer_ and _Customer_ may enforce this agreement.

<a id="assignment"></a>
### Assignment

Each side may assign all its rights, licenses, and obligations under this agreement, as a whole, to a new legal entity created to change its jurisdiction or legal form of organization, or to an entity that acquires substantially all of its assets or enough securities to control its management. Otherwise, each side needs _Permission_ to assign any right or license under this agreement. Attempts to assign against the terms of this agreement will have no legal effect.

<a id="lawsuits"></a>
### Lawsuits

<a id="lawsuit"></a>
#### Lawsuit

**Lawsuit** means a lawsuit brought by one side against the other, related to this agreement or the _Software_.

<a id="courts"></a>
#### Courts

**Developer's Local Courts** means the state and federal courts with jurisdiction at _Developer's Address_.

<a id="forum"></a>
#### Forum

Both sides agree to bring any _Lawsuit_ in _Developer's Local Courts_.

<a id="exclusive-jurisdiction"></a>
#### Exclusive Jurisdiction

Both sides consent to the exclusive jurisdiction of _Developer's Local Courts_. Both sides may enforce judgments from _Developer's Local Courts_ in other jurisdictions.

<a id="inconvenient-forum-waiver"></a>
#### Inconvenient Forum Waiver

Both sides waive any objection to venue for any _Lawsuit_ in _Developer's Local Courts_ and any claim that the other brought any _Lawsuit_ in _Developer's Local Courts_ in an inconvenient forum.

<a id="definitions"></a>
## Definitions

1. **Concurrent Users** means the number of _Users_ logged into or using the _Software_ at any given time.

2. **Customer Personnel** means _Customer_'s employees and each _Customer_ subsidiary's employees, as well as independent contractors providing services to _Customer_.

3. **Documentation** means documentation for the _Software_.

4. **Indemnification** means indemnifying and holding harmless for all liability, expenses, damages, and costs.

5. **Infringement Claim** means a court order against _Customer_'s use of the _Software_ based on a claim that it infringes any _Intellectual Property Right_ or breaks any law, or a threat of that kind of claim that _Developer_ believes credible.

6. **Intellectual Property Right** means any patent, copyright, trademark, or trade secret right, or any other legal right typically referred to as an intellectual property right.

7. **Latest Version of the Software** means the latest of the _Covered Versions_ of the _Software_.

8. **Legal Claims** means claims, demands, lawsuits, and other legal actions.

9. **License Keys** means license keys or other secrets used to validate rights to use the _Software_.

10. **Notice** means a written communication from one side to the other per [Notice Process](#notice-process).

11. **Permission** means _Notice_ of consent ahead of time.

12. **Public Software Repository** means a website or Internet service that provides free-of-charge downloads of _Publicly Licensed_ _Software_.

13. **Public License** means a license to the public, or to everyone who receives a copy.

14. **Publicly Licensed** means published with a notice of a _Public License_.

15. **Permitted Use of the Software** means _Customer_'s use of the _Software_, other than _Use of the Software at Customer's Own Risk_.

16. **Prepaid Fees** means fees _Customer_ prepaid under this agreement for time remaining in the term of this agreement.

17. **Running Instances** means the number of copies of the _Software_ _Customer_ runs at any given time.

18. **Software Dependencies** means software from others that the _Software_ depends on, installs, configures, or links, directly or indirectly.

19. **Use of the Software at Customer's Own Risk** means:

    1. use of the _Software_ in breach of this agreement

    2. use of the _Software_ with changes, additions, or in combination with other software, computers, or data, in a way that infringes someone else's _Intellectual Property Right_ or breaks the law, if use of the _Software_ as provided, as described by the _Documentation_, would not

    3. use of other than the _Latest Version of the Software_ that infringes someone else's _Intellectual Property Right_ or breaks the law, if _Customer_ had _Notice_ that using the _Latest Version of the Software_ would not

    4. unauthorized use of the _Software_ with _Customer_ _License Keys_

20. **Users** means _Customer Personnel_ using the _Software_.

21. **Developer's Address** means the address that _Developer_ gives along with its signature to the _Order Form_.
